# Home of mnmetro Library
[![codecov](https://codecov.io/gh/trjahnke/mnmetro/branch/master/graph/badge.svg)](https://codecov.io/gh/trjahnke/mnmetro) [![Maintainability](https://api.codeclimate.com/v1/badges/4f55f0d42659d4c36b48/maintainability)](https://codeclimate.com/github/trjahnke/mnmetro/maintainability) [![Test Coverage](https://api.codeclimate.com/v1/badges/4f55f0d42659d4c36b48/test_coverage)](https://codeclimate.com/github/trjahnke/mnmetro/test_coverage) [![Documentation Status](https://readthedocs.org/projects/mnmetro/badge/?version=latest)](https://mnmetro.readthedocs.io/en/latest/?badge=latest)



## What is mnmetro?
mnmetro is a Python3 wrapper built for the Minnesota Metro Tranist API.

## Installation
You can install mnmetro using [pip](https://pypi.org)
```bash
$ pip install mnmetro
```

#### Development
To be add when setup. Otherwise PR's are always welcome.

## Setup
All you have to do to start using mnmetro is import it. [Then checkout the objects you can initialize!](/inner-workings/functions)
```python
import mnmetro
```
